/* This file is part of GNOME Games. License: GPL-3.0+. */

.content-view {
	background-color: @theme_base_color;
}

gamesgamethumbnail {
	background-color: mix (@theme_base_color, @theme_bg_color, 0.5);
	border-width: 1px;
	border-style: solid;
	border-radius: 2px;
	border-color: @theme_bg_color;
	color: @theme_fg_color;
}

gamescollectioniconview flowboxchild {
	min-width: 128px;
}

gamescollectioniconview.large flowboxchild {
	min-width: 256px;
}

/* Styles from libhandy example, this should be kept in sync with this:
 * https://source.puri.sm/Librem5/libhandy/blob/master/examples/style.css
 */

stacksidebar list {
	border-left-width: 0px;
	border-right-width: 0px;
}

